@@ -44,8 +44,8 @@ public:
         UpdateConnection
     };
 
-    explicit Handler(QObject* parent = 0);
-    virtual ~Handler();
+    explicit Handler(QObject* parent = nullptr);
+    ~Handler() override;
 
 public Q_SLOTS:
     /**
