@@ -32,10 +32,10 @@ class OpenswanAuthDialog : public SettingWidget
     Q_OBJECT
     Q_DECLARE_PRIVATE(OpenswanAuthDialog)
 public:
-    explicit OpenswanAuthDialog(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = 0);
-    ~OpenswanAuthDialog();
+    explicit OpenswanAuthDialog(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = nullptr);
+    ~OpenswanAuthDialog() override;
     virtual void readSecrets();
-    virtual QVariantMap setting() const;
+    QVariantMap setting() const override;
 
 private:
     OpenswanAuthDialogPrivate *const d_ptr;
